@@ -2,33 +2,36 @@ import datetime
 import json
 import os
 from concurrent.futures import ThreadPoolExecutor
-from pathlib import Path
+
 from typing import Any, Dict, List
-
 from google.cloud import storage
-
+import os
+from dotenv import load_dotenv
+load_dotenv()
 
 class Cloudstore:
-    def __init__(self, stage="staging"):
-        BUCKET_NAME = f"ph-gandai-{stage}"
-        self.bucket_name = BUCKET_NAME
-        self.client = storage.Client(project=os.getenv("PROJECT_NAME", "gandai-dev"))
-        self.bucket = self.client.get_bucket(self.bucket_name)
+    def __init__(self):
+        GCP_PROJECT = os.getenv("GCP_PROJECT", "gandai-beta")
+        GCP_STAGE = os.getenv("GCP_STAGE", "dev")
+        self.BUCKET_NAME = f"{GCP_PROJECT}-{GCP_STAGE}"
+        self.client = storage.Client(project=GCP_PROJECT)
+        self.bucket = self.client.get_bucket(self.BUCKET_NAME)
 
     def keys(self, prefix="") -> List[str]:
         keys = [
             blob.name
-            for blob in self.client.list_blobs(self.bucket_name, prefix=prefix)
+            for blob in self.client.list_blobs(self.BUCKET_NAME, prefix=prefix)
         ]
         return keys
 
+    def delete(self, key: str) -> None:
+        blob = self.bucket.blob(key)
+        blob.delete()
+
     def __getitem__(self, key: str) -> json:
         blob = self.bucket.blob(key)
         return json.loads(blob.download_as_string())
 
-    async def get(self, key: str) -> json:
-        return self.__getitem__(key)
-
     def __setitem__(self, key: str, data) -> None:
         blob = self.bucket.blob(key)
         blob.upload_from_string(json.dumps(data))
