@@ -3,16 +3,15 @@ import random
 from dataclasses import asdict, dataclass, field
 from hashlib import md5
 from time import time
-
-
-from dacite import from_dict
+import os
 from twilio.rest import Client
 
 from gandai.datastore import Cloudstore
-# from gandai.models.User import user_exists # create_user 
+
+# from gandai.models.User import user_exists # create_user
 
 ds = Cloudstore()
-twilio_client = Client(ds["env/TWILIO_APP"], ds["env/TWILIO_TOKEN"])
+twilio_client = Client(os.getenv("TWILIO_APP"), os.getenv("TWILIO_TOKEN"))
 
 
 @dataclass
@@ -26,7 +25,7 @@ class Auth:
     def __post_init__(self):
         assert len(str(self.code)) == 6
         assert len(str(self.phone)) == 10
-        SEVEN_DAYS = (7 * 86400)
+        SEVEN_DAYS = 7 * 86400
         self.expires = int(time()) + SEVEN_DAYS
         self.key = f"auth/{self.phone}/{self.expires}"
         self.token = md5(self.key.encode()).hexdigest()
@@ -35,7 +34,7 @@ class Auth:
 def _send_code(auth: Auth) -> None:
     message = twilio_client.messages.create(
         to=auth.phone,
-        from_=ds["env/TWILIO_NUMBER"],
+        from_=os.getenv("TWILIO_NUMBER"),
         body=f"{auth.code} is your G&AI Research authentication code.",
     )
     print(f"Login Sent to {auth.phone}")
@@ -49,14 +48,14 @@ def send_code(phone: str) -> None:
     _send_code(auth)
 
 
-def authenticate(code: int) -> Auth:
+def authenticate(code: str) -> Auth:
     keys = ds.keys("auth/")[1::]
     df = pd.DataFrame(ds.load_async(keys))
-    df = df[df['expires'] > int(time())]
-    df = df[df['code'] == code]
-    if len(df) > 0: 
+    df = df[df["expires"] > int(time())]
+    df = df[df["code"] == code]
+    if len(df) > 0:
         # could parse to Auth and back to dict
-        return df.to_dict(orient='records')[0]
+        return df.to_dict(orient="records")[0]
     else:
         return None
 
