@@ -14,6 +14,7 @@ class Comment:
     domain: str  # domain
     body: str
     created: int = field(init=False)
+    public: bool = True
 
     def __post_init__(self):
         self.created = int(time())
@@ -26,3 +27,9 @@ def post_comment(actor_key: str, search_key: str, domain: str, body: str) -> dic
     )
     ds[comment.key] = asdict(comment)
     return asdict(comment)
+
+def soft_delete(key: str) -> dict:
+    comment = ds[key]
+    comment['public'] = False
+    ds[key] = comment
+    return comment
\ No newline at end of file
